# SEO Studio

## Description
SEO Studio is a Drupal module that provides a full preview of meta tags across major social platforms and search engines.

## Dependencies
- Drupal Core: ^8 | ^9 | ^10
- Metatag
- Metatag Open Graph
- Metatag Twitter Cards

## Installation
1. Download and place the module in your Drupal installation's `modules` directory.
2. Enable the module via the Drupal admin interface (`/admin/modules`) or using Drush:
   ```
   drush en seostudio
   ```

## Configuration
1. Navigate to `/admin/config/search/flaregpt/metatags` to access the SEO Studio Configuration form.
2. Configure the module settings as needed. Choose for which content types you wish to enable the SEO tab.

## Permissions
The module defines the following permission:
- The module uses the permissions of the Metatag module `administer metatags`. Users with this permission will be able to access the nodes SEO tab.
- `administer flaregpt`: Allows users to access and manage SEO Studio configuration.

Ensure that appropriate roles are granted this permission to use the module effectively.

## Usage
1. After installation and configuration, navigate to any node page.
2. Access the SEO preview by clicking the SEO tab next to the Edit and Delete tabs, or via visiting `/node/{node}/seo`, where `{node}` is the node ID.
3. The preview will display how your content appears on various social platforms and search engines based on the meta tags.
4. It will also contain a `Raw metatags` fieldset where the actual code of the metatags is visible.

## Features
1. Meta Tag Preview: Visualize how your content appears on social platforms and search engines.
2. Multi-language Support: Works with translatable entities to provide language-specific meta information.

## API/Hooks
The module implements the following hooks:

### hook_theme()
Defines the 'seo_studio' theme, which is used to render the SEO preview.

### hook_page_attachments_alter()
Alters page attachments to include JSON-LD structured data on node pages.

## Services
The module provides the following service:

- `seostudio.node_data_fetcher`: A service for fetching meta tag data for nodes.

## Extending the Module
Developers can extend the functionality of SEO Studio by:
1. Implementing custom meta tag providers.
2. Extending the `NodeDataFetcher` service to include additional data sources.
3. Altering the SEO preview theme to customize the display.

## Troubleshooting
If you encounter issues with meta tag previews:
1. Ensure all dependencies are correctly installed and enabled.
2. Check that the necessary permissions are granted to the appropriate roles.
3. Verify that meta tags are properly configured for your content types.

For more information or support, please refer to the module's issue queue on Drupal.org.